@@ -8,10 +8,6 @@ fn build_windows() {
     );
 }
 
-fn build_linux_netbsd() {
-    println!("cargo:rustc-link-lib=X11");
-}
-
 fn build_macos() {
     println!("cargo:rustc-link-lib=framework=Foundation");
     println!("cargo:rustc-link-lib=framework=IOKit");
@@ -21,7 +17,6 @@ fn main() {
     match env::var("CARGO_CFG_TARGET_OS").as_ref().map(|x| &**x) {
         Ok("macos") => build_macos(),
         Ok("windows") => build_windows(),
-        Ok("linux") | Ok("netbsd") => build_linux_netbsd(),
         _ => {}
     }
 }
